Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(361)

Unified Diff: Source/web/ServiceWorkerGlobalScopeProxy.h

Issue 1115923002: workers: Rename WorkerThread to WorkerScript. Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: . Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: Source/web/ServiceWorkerGlobalScopeProxy.h
diff --git a/Source/web/ServiceWorkerGlobalScopeProxy.h b/Source/web/ServiceWorkerGlobalScopeProxy.h
index 3ebd55b30901b173f9e3d8962aec284183d02eac..c29fc1397cfbca97de0b78772fcb90d9471bfbf5 100644
--- a/Source/web/ServiceWorkerGlobalScopeProxy.h
+++ b/Source/web/ServiceWorkerGlobalScopeProxy.h
@@ -57,7 +57,7 @@ class WebServiceWorkerRequest;
// e.g. onfetch.
//
// An instance of this class is supposed to outlive until
// workerThreadTerminated() is called by its corresponding
// WorkerGlobalScope.
class ServiceWorkerGlobalScopeProxy final
: public WebServiceWorkerContextProxy
@@ -89,7 +89,7 @@ public:
virtual void workerGlobalScopeStarted(WorkerGlobalScope*) override;
virtual void workerGlobalScopeClosed() override;
virtual void willDestroyWorkerGlobalScope() override;
- virtual void workerThreadTerminated() override;
+ virtual void workerScriptTerminated() override;
private:
ServiceWorkerGlobalScopeProxy(WebEmbeddedWorkerImpl&, Document&, WebServiceWorkerContextClient&);
@@ -57,7 +57,7 @@ class WebServiceWorkerRequest;
//
// An instance of this class is supposed to outlive until
-// workerThreadTerminated() is called by its corresponding
+// workerScriptTerminated() is called by its corresponding
// WorkerGlobalScope.
class ServiceWorkerGlobalScopeProxy final

Powered by Google App Engine
This is Rietveld 408576698